==> cursive-extras-0.2.0.crate: cursive-extras-0.2.0/src/funcs.rs <==
use cursive_core::{
    Cursive,
    With,
    view::Nameable,
    event::{Event, Key},
    views::{EditView, Dialog, OnEventView, NamedView},
    theme::{
        PaletteColor,
        Color,
        BaseColor,
        ColorStyle,
        BorderStyle,
        Theme
    }
};
use std::fmt::Display;

/// Convenience function that generates a better looking Cursive theme
/// 
/// # Example
/// ```
/// use cursive_extras::*;
/// 
/// let mut root = cursive::default();
/// root.set_theme(better_theme());
/// ```
pub fn better_theme() -> Theme {
    let mut theme_def = Theme::default();
    theme_def.shadow = false;
    theme_def.palette[PaletteColor::Background] = Color::TerminalDefault;
    theme_def.palette[PaletteColor::Primary] = Color::Light(BaseColor::White);
    theme_def.palette[PaletteColor::View] = Color::TerminalDefault;
    theme_def.palette[PaletteColor::Highlight] = Color::Light(BaseColor::Blue);
    theme_def.palette[PaletteColor::HighlightText] = Color::Dark(BaseColor::Black);
    theme_def.palette[PaletteColor::Secondary] = Color::Dark(BaseColor::Blue);
    theme_def.palette[PaletteColor::TitlePrimary] = Color::Light(BaseColor::Blue);
    theme_def.borders = BorderStyle::Outset;
    theme_def
}

/// Convenience function that creates a dialog that runs a callback if the
/// user selects "Yes"
/// 
/// # Example
/// ```
/// use cursive_extras::*;
/// 
/// let mut root = cursive::default();
/// root.add_layer(confirm_dialog("Are you sure?", "Are you sure?", |view| view.quit()));
/// ```
pub fn confirm_dialog<C, T, U>(title: T, text: U, cb: C) -> OnEventView<Dialog>
    where
        C: Fn(&mut Cursive) + 'static,
        T: Display,
        U: Display
{
    Dialog::text(text.to_string())
        .dismiss_button("No")
        .button("Yes", cb)
        .title(title.to_string())
        .wrap_with(OnEventView::new)
        .on_event(Event::Key(Key::Esc), |v| { v.pop_layer(); })
}

/// Convenience function that shows a user a dialog box
/// with a message that includes a back button
/// 
/// # Example
/// ```
/// use cursive_extras::*;
/// 
/// let mut root = cursive::default();
/// root.add_layer(info_dialog("Info", "This is important!"));
/// ```
pub fn info_dialog<T: Display, U: Display>(title: T, text: U) -> OnEventView<Dialog> {
    Dialog::text(text.to_string())
        .dismiss_button("Back")
        .title(title.to_string())
        .wrap_with(OnEventView::new)
        .on_event(Event::Key(Key::Esc), |v| { v.pop_layer(); })
}

/// Convenience function that creates a named `EditView` that has a better
/// looking style and can optionally act as a password entry box
/// 
/// # Example
/// ```
/// use cursive::views::Dialog;
/// use cursive_extras::*;
/// 
/// let mut root = cursive::default();
/// root.add_fullscreen_layer(
///     Dialog::around(styled_editview("yes", "edit", false))
///         .button("Quit", |view| view.quit())
///         .title("Styled EditView Example")
/// );
/// root.run();
/// ```
pub fn styled_editview<C: Display>(content: C, view_name: &'static str, password: bool) -> NamedView<EditView> {
    let input_style = ColorStyle::new(
        Color::Dark(BaseColor::Blue),
        Color::Light(BaseColor::White),
    );
    let view = EditView::new().content(content.to_string()).style(input_style).filler(" ");

    if password {
        view.secret().with_name(view_name)
    }
    else {
        view.with_name(view_name)
    }
}

==> cursive-extras-0.2.1.crate: cursive-extras-0.2.1/src/funcs.rs <==
use cursive_core::{
    Cursive,
    With,
    view::Nameable,
    event::{Event, Key},
    views::{EditView, Dialog, OnEventView, NamedView},
    theme::{
        PaletteColor,
        Color,
        BaseColor,
        ColorStyle,
        BorderStyle,
        Theme
    }
};
use std::fmt::Display;

/// Convenience function that generates a better looking Cursive theme
/// 
/// # Example
/// ```
/// use cursive_extras::*;
/// 
/// let mut root = cursive::default();
/// root.set_theme(better_theme());
/// ```
pub fn better_theme() -> Theme {
    let mut theme_def = Theme::default();
    theme_def.shadow = false;
    theme_def.palette[PaletteColor::Background] = Color::TerminalDefault;
    theme_def.palette[PaletteColor::Primary] = Color::Light(BaseColor::White);
    theme_def.palette[PaletteColor::View] = Color::TerminalDefault;
    theme_def.palette[PaletteColor::Highlight] = Color::Light(BaseColor::Blue);
    theme_def.palette[PaletteColor::HighlightText] = Color::Dark(BaseColor::Black);
    theme_def.palette[PaletteColor::Secondary] = Color::Dark(BaseColor::Blue);
    theme_def.palette[PaletteColor::TitlePrimary] = Color::Light(BaseColor::Blue);
    theme_def.borders = BorderStyle::Outset;
    theme_def
}

/// Convenience function that creates a dialog that runs a callback if the
/// user selects "Yes"
/// 
/// # Example
/// ```
/// use cursive_extras::*;
/// 
/// let mut root = cursive::default();
/// # root.set_theme(better_theme());
/// root.add_layer(confirm_dialog("Are you sure?", "Are you sure?", |view| view.quit()));
/// root.run();
/// ```
pub fn confirm_dialog<C, T, U>(title: T, text: U, cb: C) -> OnEventView<Dialog>
    where
        C: Fn(&mut Cursive) + 'static,
        T: Display,
        U: Display
{
    Dialog::text(text.to_string())
        .dismiss_button("No")
        .button("Yes", cb)
        .title(title.to_string())
        .wrap_with(OnEventView::new)
        .on_event(Event::Key(Key::Esc), |v| { v.pop_layer(); })
}

/// Convenience function that shows a user a dialog box
/// with a message that includes a back button
/// 
/// # Example
/// ```
/// use cursive_extras::*;
/// 
/// let mut root = cursive::default();
/// # root.set_theme(better_theme());
/// root.add_layer(info_dialog("Info", "This is important!"));
/// root.run();
/// ```
pub fn info_dialog<T: Display, U: Display>(title: T, text: U) -> OnEventView<Dialog> {
    Dialog::text(text.to_string())
        .dismiss_button("Back")
        .title(title.to_string())
        .wrap_with(OnEventView::new)
        .on_event(Event::Key(Key::Esc), |v| { v.pop_layer(); })
}

/// Convenience function that creates a named `EditView` that has a better
/// looking style and can optionally act as a password entry box
/// 
/// # Example
/// ```
/// use cursive::views::Dialog;
/// use cursive_extras::*;
/// 
/// let mut root = cursive::default();
/// # root.set_theme(better_theme());
/// root.add_fullscreen_layer(
///     Dialog::around(styled_editview("yes", "edit", false))
///         .button("Quit", |view| view.quit())
///         .title("Styled EditView Example")
/// );
/// root.run();
/// ```
pub fn styled_editview<C: Display>(content: C, view_name: &'static str, password: bool) -> NamedView<EditView> {
    let input_style = ColorStyle::new(
        Color::Dark(BaseColor::Blue),
        Color::Light(BaseColor::White),
    );
    let view = EditView::new().content(content.to_string()).style(input_style).filler(" ");

    if password {
        view.secret().with_name(view_name)
    }
    else {
        view.with_name(view_name)
    }
}
